@@ -9,7 +9,7 @@
 #include <iostream>
 #include <string>
 
-#include <gtest/gtest.h>
+#include "common.h"
 
 #include "file-helpers.h"
 
