@@ -1,12 +1,11 @@
 #include <config.h>
 #include <apt-pkg/fileutl.h>
-#include <apt-pkg/string_view.h>
 #include <apt-pkg/strutl.h>
 #include <limits>
 #include <string>
 #include <vector>
 
-#include <gtest/gtest.h>
+#include "common.h"
 
 #include "file-helpers.h"
 
@@ -180,6 +179,24 @@ TEST(StrUtilTest,Base64Encode)
    EXPECT_EQ("/A==", Base64Encode("\xfc"));
    EXPECT_EQ("//8=", Base64Encode("\xff\xff"));
 }
+TEST(StrUtilTest,Base64Decode)
+{
+   EXPECT_EQ(Base64Decode("QWxhZGRpbjpvcGVuIHNlc2FtZQ=="), "Aladdin:open sesame");
+   EXPECT_EQ(Base64Decode("cGxlYXN1cmUu"), "pleasure.");
+   EXPECT_EQ(Base64Decode("bGVhc3VyZS4="), "leasure.");
+   EXPECT_EQ(Base64Decode("ZWFzdXJlLg=="), "easure.");
+   EXPECT_EQ(Base64Decode("YXN1cmUu"), "asure.");
+   EXPECT_EQ(Base64Decode("c3VyZS4="), "sure.");
+   EXPECT_EQ(Base64Decode("dXJlLg=="), "ure.");
+   EXPECT_EQ(Base64Decode("cmUu"), "re.");
+   EXPECT_EQ(Base64Decode("ZS4="), "e.");
+   EXPECT_EQ(Base64Decode("Lg=="), ".");
+   EXPECT_EQ(Base64Decode(""), "");
+   EXPECT_EQ(Base64Decode("IA=="), "\x20");
+   EXPECT_EQ(Base64Decode("/w=="), "\xff");
+   EXPECT_EQ(Base64Decode("/A=="), "\xfc");
+   EXPECT_EQ(Base64Decode("//8="), "\xff\xff");
+}
 static void ReadMessagesTestWithNewLine(char const * const nl, char const * const ab)
 {
    SCOPED_TRACE(SubstVar(SubstVar(nl, "\n", "n"), "\r", "r") + " # " + ab);
@@ -259,7 +276,7 @@ TEST(StrUtilTest,QuoteString)
    EXPECT_EQ("Eltville-Erbach", DeQuoteString(QuoteString("Eltville-Erbach", "")));
 }
 
-static void EXPECT_STRTONUM(APT::StringView const str, bool const success, unsigned long const expected, unsigned const base)
+static void EXPECT_STRTONUM(std::string_view const str, bool const success, unsigned long const expected, unsigned const base)
 {
    SCOPED_TRACE(std::string(str.data(), str.length()));
    SCOPED_TRACE(base);
@@ -319,7 +336,8 @@ TEST(StrUtilTest,RFC1123StrToTime)
       time_t t;
       EXPECT_TRUE(RFC1123StrToTime("Sun, 06 Nov 1994 08:49:37 GMT", t));
       EXPECT_EQ(784111777, t);
-   } {
+   }
+   {
       time_t t;
       EXPECT_TRUE(RFC1123StrToTime("Sun, 6 Nov 1994 08:49:37 UTC", t));
       EXPECT_EQ(784111777, t);
